==> pagebot-0.6.tar.gz: pagebot-0.6/Lib/pagebot/contributions/filibuster/content/commercial.py <==
# -*- coding: UTF-8 -*-

"""
        history
        A template for new submodules
        
        A ContentWriter version of the old letterror content module
        added for compatibility.
- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
"""

__version__ = '4.0'
__author__ = "erik"

content = {
        'business_headline': ['<#^,com_corporatenames#>'],
        'business_ankeiler': ['<#^,com_corporatenames#>'],
        
        'commercial_shortheadline':['<#^,com_corporatenames#>'],
        'commercial_section':['Commercial','Classifieds','Classifieds','Classifieds','Havings','Things to have'],
        'com_adjectives' : [
            "adaptable", "All-american", "american", "annual", "artificial", "bang", "Barbequed", 
            "Bi-Rite", "Black", "Blue", "Breed", "Breezy", "bruised", "caffein free", "calving", "Cheezy", 
            "compatible", "concentrated", "country style", "cristalised", "d-caf (decaf)", "Day-Glo", "digital", 
            "digitised", "direct", "diseased", "ego", "enriched", "european", "excellent", "EXTRA", "extra strength", 
            "extra wide", "fecal", "First", "freez-dried", "fried", "Friendly", "garanteed", "genuine", "greasy", 
            "Green", "hand picked", "Hi-cal", "Hi-fibre", "hi-volume", "hypodermic", "icky", "important", 
            "innovative", "instant", "international", "leading", "Lite", "Lo-cal", "lo-Fi", "Low calories", 
            "marketing", "maximum strenght", "more", "Multi", "New", "No-Burn", "no-cholestorol", 
            "Now!", "nu & improovd", "nu taste", "official", "only", "over sampling", "pathetic", 
            "perfect", "personal", "personalised", "political", "politically correct", "portable", "potable", 
            "pre-packaged", "radical", "radioactive", "Random Access", "real", "Recycled", "Red", 'Green', 'gr33n',
            'h3110!', 'national', 'international', 'digital', 'personal', 'demo',
            "retroactive", "serious", "sexy", "Shitty", "skilled", "Smelly", "special", 
            "Spoungy", "strong", "stronger", "supercharged", "supreme", "tasty", "tax free", "Teal",
            "techno", "traditional", "Transparant!", "turbo", "Unique", "Used", "Vacuum", "washable", 
            "washing", "White", "Wide", "Xtra-Lite", "yucky", "yuk", "pro", "super", "salivating", "excellent", "prohibitive",
            "free", "reduced", "electronic", "nano", "micro", "mini", "grand", "massive", "big", "tall", "wet", "best",
            "****", "four star!", u"Æ", u"Å", "@", u"ï", u"©", u"°", "*", "&", '?', u'ø', "brand new",
            'micro', 'mini', 'macro', 'giga', 'tera', 'peta', '!', '!!'
                ],
        'com_nouns' : [
            "$", "After-Burn", "Alarm", "assistant", "AMERICAN", "bellies", "Betrayal", "BitPull", "blob", "booze", 
            "BRAL", "Broadcast", "business", "carbohydrates", "chicken", "chocolate", "cleaner", "Coffee",
             "colon", "convenience", "cookies", "credit card", "dang", "design", "dinosaur", "Disease", "dog", 
            "doggie", "drops", "Drug!", "enhancer", "Future", "holiday", "house", "Intelligence", "Jello", 
            "latex", "LettError", "mall", "measels", "meat", "media", "morsels", "mother", "multimedia", 
            "music", "nite", "Nonsense", "nutrition", "offer", "office", "peanut butter", "pep", "phone", 
            "Pill", "politician", "pork", "powder", "power", "product", "prosthetic", "protein", "punch", 
            "quality", "rubber bank", "Safe!", "schrift", "sex", "shit", "snooze", "snort", "strength", 
            "television", "thang", "thought", "tranquilizer", "type", "Vulcan", "wipers", "world", "Wump!",
            'video', 'programme', 'specimen', 'drive', 'matrix', 'activity', 'network', 'intranet', 'local', 'connection'
                ],
        'com_letterrors':[
            "letterror", 'LETTERROR', 'LTTRRR', u'Lt›rÆrR', 'LetterRor',
            """LTT
            RRR
            SND""",
            'randomfonts',
            'bitpull',
            'flipperfonts',
            'gifwrap',
            'fbt',
            'pure fbt',
            'pythography'        
                ],
        'com_bylines':[
            u"it’s pure fbt!",
            u"We’re The Phone Company.", "We Make The Things That Cool Your Food.", 
            "A Registered Trademark of LettError.", "Contains no artificial flavorings.",
            "Contains no inedible parts.", "Contains no content.", "www.letterror.com",
            "Visit our website Now!", "Part No. 123009", "Money in The Bank.", "Virtually No Interest.",
            "Stupid pretentious video ART.", "Manchester", "London", "Amsterdam", "Paris", "New York",
            "0% financing.", "10% extra.", "10% less.", "10% more.", "10 pack!", "15% Vol.", 
            "24 hours!", "30 D MBG.", "7 day no quibble money back guarantee.", 
            "All major credit cards accepted.", "Amount per serving.",  u"Appelation controlée.", 
            "Buy one, and get one for free!", "Complete and Unabridged", "Daily allowance", 
            "Dial one of these numbers.", u"Don’t buy this at home.", u"Don’t wait.", "For kids!", "For pets!", 
            "Free delivery.", "Free inside!", "Free refill.", "Fresh!", "Freshly Killed Each Morning!", 
            "Gotta get it...", "I am satisfied!", "I have never felt so fresh before.", "Illegal when prohibited by law.", 
            "It changed my life completely.", "It fills me up!", u"It’s natural!", "Just add water.", 
            "Made in Europe.", "Made in HongKong.", "Made in Japan", "Made in USA.", "Mister card accepted.", 
            "Net WT 12 OZ (340 grams).", u"New & improved.", "Next morning delivery.", "No conservatives.", 
            "No secret ingredients.", "Not for internal use.", "Not funny!", "Now with improved GT.", 
            "Order now.", "Printed in England.", "Provides 8 essential vitamins & iron.", "Taste the difference.", 
            "The lowest prices.", "This will cost you absolutely nothing!", "Try it!", "Used to be cool.", 
            "Values by formulation and analysis.", "Void when prohibited by law.", "With wings!", 
            u"Your kids’ll love it!", 'Have a look at our website.', 'http://www.letterror.com', 'Prions!',
            u"I can’t believe it’s chicken!"
                ],
        'com_adjectivenouns':[
                '<#com_adjectives#>',
                '<#com_nouns#>',
                ],
        'com_writecopy':
            [
            "<#com_adjectivenouns#>\n<#com_nouns#>\n<#com_bylines#>"    
                    ],
        'com_corporatenames':
            [
            "<#creditcard#>",
            "<#company_oldschool#>",
            "<#company_consolidated#>",
            "<#corporation_japanese#>",
            "<#company#>",
            "<#newspapers#>",
            "<#air_class#>",
            "<#air_carrier#>",
                    ],
        'com_businesscardblurb':[
            "<#eMail#>",
            "<#j_thing#>",
            "<#jobs_executive#>",
            "<#address#>",
                    ],
        'com_creditcardblurb':[
            "<#creditcard_issued#>",
            "<#creditcard_number#>",
            "<#creditcard_validuntil#>",
                    ],    
        }

==> pagebot-0.9.7.tar.gz: pagebot-0.9.7/Lib/pagebot/contributions/filibuster/content/commercial.py <==
# -*- coding: UTF-8 -*-

"""
A template for new submodules
        
A ContentWriter version of the old letterror content module
added for compatibility.
"""

__version__ = '4.0'
__author__ = "erik"

content = {
        'business_headline': ['<#^,com_corporatenames#>'],
        'business_ankeiler': ['<#^,com_corporatenames#>'],
        
        'commercial_shortheadline':['<#^,com_corporatenames#>'],
        'commercial_section':['Commercial','Classifieds','Classifieds','Classifieds','Havings','Things to have'],
        'com_adjectives' : [
            "adaptable", "All-american", "american", "annual", "artificial", "bang", "Barbequed", 
            "Bi-Rite", "Black", "Blue", "Breed", "Breezy", "bruised", "caffein free", "calving", "Cheezy", 
            "compatible", "concentrated", "country style", "cristalised", "d-caf (decaf)", "Day-Glo", "digital", 
            "digitised", "direct", "diseased", "ego", "enriched", "european", "excellent", "EXTRA", "extra strength", 
            "extra wide", "fecal", "First", "freez-dried", "fried", "Friendly", "garanteed", "genuine", "greasy", 
            "Green", "hand picked", "Hi-cal", "Hi-fibre", "hi-volume", "hypodermic", "icky", "important", 
            "innovative", "instant", "international", "leading", "Lite", "Lo-cal", "lo-Fi", "Low calories", 
            "marketing", "maximum strenght", "more", "Multi", "New", "No-Burn", "no-cholestorol", 
            "Now!", "nu & improovd", "nu taste", "official", "only", "over sampling", "pathetic", 
            "perfect", "personal", "personalised", "political", "politically correct", "portable", "potable", 
            "pre-packaged", "radical", "radioactive", "Random Access", "real", "Recycled", "Red", 'Green', 'gr33n',
            'h3110!', 'national', 'international', 'digital', 'personal', 'demo',
            "retroactive", "serious", "sexy", "Shitty", "skilled", "Smelly", "special", 
            "Spoungy", "strong", "stronger", "supercharged", "supreme", "tasty", "tax free", "Teal",
            "techno", "traditional", "Transparant!", "turbo", "Unique", "Used", "Vacuum", "washable", 
            "washing", "White", "Wide", "Xtra-Lite", "yucky", "yuk", "pro", "super", "salivating", "excellent", "prohibitive",
            "free", "reduced", "electronic", "nano", "micro", "mini", "grand", "massive", "big", "tall", "wet", "best",
            "****", "four star!", "Æ", "Å", "ï", "©", "°", "*", "&", '?', 'ø', "brand new",
            'micro', 'mini', 'macro', 'giga', 'tera', 'peta', '!', '!!'
                ],
        'com_nouns' : [
            "$", "After-Burn", "Alarm", "assistant", "AMERICAN", "bellies", "Betrayal", "BitPull", "blob", "booze", 
            "BRAL", "Broadcast", "business", "carbohydrates", "chicken", "chocolate", "cleaner", "Coffee",
             "colon", "convenience", "cookies", "credit card", "dang", "design", "dinosaur", "Disease", "dog", 
            "doggie", "drops", "Drug!", "enhancer", "Future", "holiday", "house", "Intelligence", "Jello", 
            "latex", "LettError", "mall", "measels", "meat", "media", "morsels", "mother", "multimedia", 
            "music", "nite", "Nonsense", "nutrition", "offer", "office", "peanut butter", "pep", "phone", 
            "Pill", "politician", "pork", "powder", "power", "product", "prosthetic", "protein", "punch", 
            "quality", "rubber bank", "Safe!", "schrift", "sex", "shit", "snooze", "snort", "strength", 
            "television", "thang", "thought", "tranquilizer", "type", "Vulcan", "wipers", "world", "Wump!",
            'video', 'programme', 'specimen', 'drive', 'matrix', 'activity', 'network', 'intranet', 'local', 'connection'
                ],
        'com_letterrors':[
            "letterror", 'LETTERROR', 'LTTRRR', 'Lt›rÆrR', 'LetterRor',
            """LTT
            RRR
            SND""",
            'randomfonts',
            'bitpull',
            'flipperfonts',
            'gifwrap',
            'fbt',
            'pure fbt',
            'pythography'        
                ],
        'com_bylines':[
            "it’s pure fbt!",
            "We’re The Phone Company.", "We Make The Things That Cool Your Food.", 
            "A Registered Trademark of LettError.", "Contains no artificial flavorings.",
            "Contains no inedible parts.", "Contains no content.", "www.letterror.com",
            "Visit our website Now!", "Part No. 123009", "Money in The Bank.", "Virtually No Interest.",
            "Stupid pretentious video ART.", "Manchester", "London", "Amsterdam", "Paris", "New York",
            "0% financing.", "10% extra.", "10% less.", "10% more.", "10 pack!", "15% Vol.", 
            "24 hours!", "30 D MBG.", "7 day no quibble money back guarantee.", 
            "All major credit cards accepted.", "Amount per serving.",  "Appelation controlée.", 
            "Buy one, and get one for free!", "Complete and Unabridged", "Daily allowance", 
            "Dial one of these numbers.", "Don’t buy this at home.", "Don’t wait.", "For kids!", "For pets!", 
            "Free delivery.", "Free inside!", "Free refill.", "Fresh!", "Freshly Killed Each Morning!", 
            "Gotta get it...", "I am satisfied!", "I have never felt so fresh before.", "Illegal when prohibited by law.", 
            "It changed my life completely.", "It fills me up!", "It’s natural!", "Just add water.", 
            "Made in Europe.", "Made in HongKong.", "Made in Japan", "Made in USA.", "Mister card accepted.", 
            "Net WT 12 OZ (340 grams).", "New & improved.", "Next morning delivery.", "No conservatives.", 
            "No secret ingredients.", "Not for internal use.", "Not funny!", "Now with improved GT.", 
            "Order now.", "Printed in England.", "Provides 8 essential vitamins & iron.", "Taste the difference.", 
            "The lowest prices.", "This will cost you absolutely nothing!", "Try it!", "Used to be cool.", 
            "Values by formulation and analysis.", "Void when prohibited by law.", "With wings!", 
            "Your kids’ll love it!", 'Have a look at our website.', 'http://www.letterror.com', 'Prions!',
            "I can’t believe it’s chicken!"
                ],
        'com_adjectivenouns':[
                '<#com_adjectives#>',
                '<#com_nouns#>',
                ],
        'com_writecopy':
            [
            "<#com_adjectivenouns#>\n<#com_nouns#>\n<#com_bylines#>"    
                    ],
        'com_corporatenames':
            [
            "<#creditcard#>",
            "<#company_oldschool#>",
            "<#company_consolidated#>",
            "<#corporation_japanese#>",
            "<#company#>",
            "<#newspapers#>",
            "<#air_class#>",
            "<#air_carrier#>",
                    ],
        'com_businesscardblurb':[
            "<#eMail#>",
            "<#j_thing#>",
            "<#jobs_executive#>",
            "<#address#>",
                    ],
        'com_creditcardblurb':[
            "<#creditcard_issued#>",
            "<#creditcard_number#>",
            "<#creditcard_validuntil#>",
                    ],    
        }
